# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic 
Versioning](https://semver.org/spec/v2.0.0.html).


## [X.X.X]

### Added

### Changed

### Deprecated

### Removed

### Fixed

## [0.1.1] - 2025-12-??  <!-- replace ?? with appropriate day once known -->

### Added
- Optional `viz` extra dependency for visualization support
- Test coverage for heatmap plotting

### Changed
- Lazy import of matplotlib to prevent forced kernel restart

### Fixed
- Heatmap plotting now supports both long-form and wide-form inputs without errors

## [0.1.0] - 2025-09-07

First public repo